#extension GL_OES_EGL_image_external : require

precision mediump float;

varying vec2 textureCoordinate;

uniform sampler2D s_texture;
uniform sampler2D inputImageTexture1;
uniform sampler2D inputImageTexture2;
uniform sampler2D holoImageTexture;
uniform lowp float spriteX;
uniform lowp float spriteY;
uniform lowp float spriteWidth;
uniform lowp float spriteHeight;
uniform lowp int spriteForeground;

void main() {
    vec2 maskCoord = vec2(textureCoordinate.y, 1.0 - textureCoordinate.x);
    highp vec4 maskColor = texture2D(inputImageTexture1, maskCoord);
    bool isForeground = spriteForeground > 0;
    bool isMask = isForeground ? false : (maskColor.r + maskColor.g + maskColor.b) > 1.0;

    bool isSprite = false;
    vec2 spriteCoord = vec2(1.0 - textureCoordinate.x, 1.0 - textureCoordinate.y);
    spriteCoord.x = (spriteCoord.x - spriteX) / spriteWidth;
    spriteCoord.y = (spriteCoord.y - spriteY) / spriteHeight;
    isSprite = (spriteCoord.x >= 0.0 && spriteCoord.x <= 1.0) && (spriteCoord.y >= 0.0 && spriteCoord.y <= 1.0);

    highp vec4 spriteColor = texture2D(inputImageTexture2, spriteCoord);
    bool isTransparent = (spriteColor.a == 0.0);

    isSprite = isSprite ? (isMask ? false : isSprite) : false;

    isSprite = isTransparent ? false : isSprite;

    vec2 bgCoord = vec2(textureCoordinate.x, 1.0 - textureCoordinate.y);

    highp vec4 bgColor = texture2D(inputImageTexture1, maskCoord);
    highp vec4 holoColor = texture2D(holoImageTexture, bgCoord);

    spriteColor.rgb = mix(bgColor.rgb,spriteColor.rgb, spriteColor.a);

    gl_FragColor = isSprite ? spriteColor : bgColor;
    gl_FragColor.a = 1.0;
    gl_FragColor.rgb = mix(gl_FragColor.rgb, holoColor.rgb, holoColor.a);
}