#extension GL_OES_EGL_image_external : require

precision mediump float;

varying vec2 textureCoordinate;

//相机的数据的纹理
uniform sampler2D s_texture;
//抠图处理结果的纹理
uniform sampler2D inputImageTexture1;
//背景的纹理
uniform sampler2D inputImageTexture2;
//描边的颜色
uniform vec4 vOutlineColor;
//脸部分的颜色，当设置的颜色值无效时，抠图区域依然显示相机的数据
uniform vec4 vMaskColor;
//是否使用背景的纹理，如果不用应该显示相机的数据
uniform bool useTexture2;
//是否进行描边
uniform bool hasOutline;
//是否使用颜色填冲抠图区域
uniform bool useMaskColor;
//是否为前置摄像头
uniform bool isFrontCamera;
//旋转角度
uniform int rotation;

void main() {
    vec2 maskCoord = isFrontCamera ? (rotation == 270 ? vec2(1.0 - textureCoordinate.y, textureCoordinate.x) : vec2(textureCoordinate.y, 1.0 - textureCoordinate.x)) : vec2(1.0 - textureCoordinate.y, 1.0 - textureCoordinate.x);
    vec2 bgCoord = vec2(1.0 - textureCoordinate.x, 1.0 - textureCoordinate.y);

    highp vec4 camColor = texture2D(s_texture, textureCoordinate);
    highp vec4 maskColor = texture2D(inputImageTexture1, maskCoord);
    highp vec4 bgColor = texture2D(inputImageTexture2, bgCoord);
    highp vec4 normal;
    bool isMask = (maskColor.r + maskColor.g + maskColor.b) >= 1.0;
    bool isStroke = maskColor.r >= 1.0 && maskColor.g == 0.0 && maskColor.b == 0.0;
    normal.rgb = mix(bgColor.rgb, camColor.rgb, maskColor.a);
    normal.a = 1.0;
    gl_FragColor = isStroke ? (hasOutline ? vOutlineColor : normal) : isMask ? (useMaskColor ? vMaskColor : normal) : (useTexture2 ? normal : texture2D(s_texture, textureCoordinate));
}